#!/usr/bin/env python3

import cv2
import numpy
import os
import sys
from PIL import Image

class FindFailed(RuntimeError):
    pass

def match(image, candidate, precision=0.9):
    precision=float(precision)
    assert(precision < 1.0)
    image_rgb = numpy.array(Image.open(image))
    image_gray = cv2.cvtColor(image_rgb, cv2.COLOR_BGR2GRAY)
    template = cv2.imread(candidate, 0)
    w, h = template.shape[::-1]
    res = cv2.matchTemplate(image_gray, template, cv2.TM_CCOEFF_NORMED)
    _, val, _, pos = cv2.minMaxLoc(res)
    if val < precision:
        raise FindFailed
    if 'DEBUG' in os.environ:
        cv2.rectangle(image_rgb, pos, (pos[0] + w, pos[1] + h), (0, 0, 255), 1)
        #cv2.imwrite('match.png', image_rgb)
        cv2.imshow('match', image_rgb)
        cv2.waitKey(0)
    return pos

try:
    pos = match(*sys.argv[1:])
    print(*pos)
except AssertionError as e:
    raise e
except FindFailed:
    print("FindFailed", file=sys.stderr)
    sys.exit(2)
except:
    sys.exit(1)
